@@ -24,11 +24,11 @@ $Id: definitions.h 1777 2010-12-05 18:28:54Z beerli $
   *----------------------------------------------------------------
   */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "3.2.6"
+#define MIGRATEVERSION "3.2.7"
 #else
 #ifdef SGI
 #undef MIGRATEVERSION
-#define MIGRATEVERSION "3.2.6"
+#define MIGRATEVERSION "3.2.7"
 #endif
 #endif
 #ifndef MIGRATESUBVERSION
@@ -65,8 +65,10 @@ $Id: definitions.h 1777 2010-12-05 18:28:54Z beerli $
 #ifdef MPI
 #include <mpi.h>
 #define FPRINTF mpi_fprintf
+#define LARGEFPRINTF mpi_fprintf2
 #else
 #define FPRINTF fprintf
+#define LARGEFPRINTF fprintf2
 #endif
 
 /* random number system */
