@@ -1527,24 +1527,23 @@ profile_tables (option_fmt * options, world_fmt * world, long *gmaxptr)
     
     if (options->profile != _NONE)
     {
-        world->buffer =
-        (char *) myrealloc (world->buffer, SUPERLINESIZE * sizeof (char));
+      //        world->buffer =
+      //  (char *) myrealloc (world->buffer, allocbufsize * sizeof (char));
         if (options->printprofsummary)
             allocate_profile_percentiles (world);
-#ifdef HAVE_STRFTIME
-        
+#ifdef HAVE_STRFTIME        
         time (&world->starttime);
-#endif
-        
+#endif        
         len = world->numpop2 + (world->options->gamma ? 1 : 0);
-#ifdef LONGSUM
-        
+#ifdef LONGSUM        
         len += world->numpop * 3;
 #endif /*LONGSUM*/
 #ifdef SLOWNET
         if (!options->readsum)
-            mpi_broadcast_results (world, world->loci,
+	  {
+	    mpi_broadcast_results (world, world->loci,
                                    pack_sumfile_buffer, unpack_sumfile_buffer);
+	  }
         mpi_broadcast_results (world,
                                world->loci + ((world->loci == 1) ? 0 : 1),
                                pack_result_buffer, unpack_result_buffer);
@@ -1573,7 +1572,7 @@ profile_tables (option_fmt * options, world_fmt * world, long *gmaxptr)
             boolean success =  print_profile_likelihood_driver (i, world, gmaxptr);
 	    if(options->profile == TABLES || options->profile == ALL)
 	      {
-		FPRINTF (world->outfile, "%s\n\n", world->buffer);
+		LARGEFPRINTF (world->outfile, world->allocbufsize+2, "%s\n\n", world->buffer);
 		//ascii_print_profile_table(options->profilemethod, world);
 #ifdef PRETTY
 		location = strlen(world->buffer);
@@ -1582,13 +1581,13 @@ profile_tables (option_fmt * options, world_fmt * world, long *gmaxptr)
 #endif 
 	      }
             world->buffer[0] = '\0';
-        }
+	  }
 #endif /*SLOWNET end of not*/
         if (myID == MASTER && options->printprofsummary)
         {
-            print_profile_percentile (world);
+            world->allocbufsize = print_profile_percentile (world);
             // print profile summary
-            FPRINTF (world->outfile, "%s\n\n", world->buffer);
+            LARGEFPRINTF (world->outfile, world->allocbufsize, "%s\n\n", world->buffer);
 #ifdef PRETTY
 	    pdf_print_profile_percentile (world);
 #endif
