@@ -16,7 +16,7 @@
  
   Copyright 2002 Peter Beerli and Joseph Felsenstein, Seattle WA
   Copyright 2003 Peter Beerli, Tallahassee FL
-  $Id: migration.h 1737 2010-10-21 16:10:07Z beerli $
+  $Id: migration.h 1782 2010-12-20 16:34:17Z beerli $
   *----------------------------------------------------------------
 */
 /**
@@ -354,6 +354,7 @@ typedef struct _bayes
   boolean has_linesize;
   long linesize;
   long progresslinesize;
+  long *mdimfilecount;
 }
 bayes_fmt;
 
@@ -603,6 +604,8 @@ typedef struct _option
   MYREAL **timemodifiers; // vector of parameter modifier vectors
 #endif
   boolean heatedswap_off;
+  boolean has_autotune;
+  MYREAL autotune;
 }
 option_fmt;
 
@@ -962,6 +965,8 @@ typedef struct _worldoption
   MYREAL generation_year;
   boolean treeinmemory;
   boolean heatedswap_off;
+  boolean has_autotune;
+  MYREAL autotune;
 }
 worldoption_fmt;
 
@@ -1042,7 +1047,7 @@ typedef struct _world
   int *profilewho;
 #endif
 #endif /*MPI*/
-  
+  long allocbufsize;
   char *buffer;   // buffer for profiles, not needed before profiletables()
   long loci;
   long skipped;   /*loci with no data */
