@@ -59,7 +59,7 @@ void prepare_header (char *var, long which, world_fmt * world);
 void print_profile_title (world_fmt * world);
 long print_profile_table (char method, long which, char *var, MYREAL likes[],
                           MYREAL **param, world_fmt * world);
-void print_profile_percentile (world_fmt * world);
+long print_profile_percentile (world_fmt * world);
 void sprint_percentile_header (char *outfile, boolean first);
 void allocate_profile_percentiles (world_fmt * world);
 void destroy_profile_percentiles (world_fmt * world);
@@ -240,6 +240,7 @@ print_profile_likelihood (long which, world_fmt * world, long *gmaxptr)
     if (world->options->printprofile)
     {
       bufsize = print_profile_table (method, which, var, likes, param, world);
+      world->allocbufsize = bufsize;
 #ifdef PRETTY
       prepare_profile_table(method, which, likes, param, world, bufsize);
 #endif
@@ -625,7 +626,7 @@ warp (long ii)
 ///
 /// print profile tables for percentiles, returns the number
 /// of failed convergences to a specific percentile.
-void
+long
 print_profile_percentile (world_fmt * world)
 {
     const MYREAL probabilities[] = SHOWGRID; //debug GRID2
@@ -744,6 +745,7 @@ print_profile_percentile (world_fmt * world)
         *buffer = (char *) myrealloc(*buffer, sizeof(char) * bufsize);
         strcat (*buffer, fp);
     }
+    return bufsize;
 }
 
 long
@@ -1722,7 +1724,6 @@ allocate_profile_percentiles (world_fmt * world)
     long i;
     long len = world->numpop2 + (world->options->gamma ? 1 : 0);
 #ifdef LONGSUM
-
     len += world->numpop*3;
 #endif /*LONGSUM*/
 
