@@ -6,17 +6,17 @@
  P R O F I L E    L I K E L I H O O D    R O U T I N E S 
  
  Peter Beerli 1997, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-$Id: profile.h 769 2007-07-15 18:29:41Z beerli $
+$Id: profile.h 1323 2008-07-25 19:13:48Z beerli $
 -------------------------------------------------------*/
 extern boolean print_profile_likelihood_driver (long which, world_fmt * world,
             long *gmaxptr);
 extern void print_profile_likelihood (long which, world_fmt * world, long *gmaxptr);
-extern void print_profile_percentile (world_fmt * world);
+extern long print_profile_percentile (world_fmt * world);
 extern void allocate_profile_percentiles (world_fmt * world);
 extern void destroy_profile_percentiles (world_fmt * world);
 extern void print_profile_title (world_fmt * world);
