@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: random.c 1756 2010-10-29 02:02:39Z beerli $
+$Id: random.c 1776 2010-12-05 14:06:10Z beerli $
 -------------------------------------------------------*/
 /* \file random.c */
 #include "sighandler.h"
@@ -572,7 +572,7 @@ void getseed(option_fmt *options)
 	  test = RANDINT (1, MAXLONG-1); 
 	}
       options->inseed = test;
-      printf("RANDOM NUMBER SEED: node=%i seed=%li\n",myID,test);
+      //      printf("RANDOM NUMBER SEED: node=%i seed=%li\n",myID,test);
 #ifdef MERSENNE_TWISTER
       getseed_mt(options);
 #else
@@ -584,7 +584,7 @@ void getseed(option_fmt *options)
     }
   else
     {
-      printf("RANDOM NUMBER SEED: node=%i seed=%li\n",myID,options->inseed);
+      printf("MASTER RANDOM NUMBER SEED: node=%i seed=%li\n",myID,options->inseed);
     }
 }
 #else
