@@ -16,7 +16,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: reporter.c 1753 2010-10-29 01:25:04Z beerli $
+$Id: reporter.c 1759 2010-11-06 01:16:48Z beerli $
  
 -------------------------------------------------------*/
 /* \file reporter.c 
@@ -434,7 +434,7 @@ void print_bayes_ess(FILE *file, world_fmt *world, long numparam, int offset,
     {
       pos += sprintf(buffer+pos,"%*.*s(*) averaged over loci.\n", offset, offset, " ");
     }
-  printf("bufsize in print_bayes_ess_buffer: %li\n",pos);
+  //  printf("bufsize in print_bayes_ess_buffer: %li\n",pos);
 #ifdef MPI
   if(file==stdout)
     {
