@@ -114,6 +114,7 @@ void write_savesum (world_fmt * world);
 /* string manipulation */
 void translate (char *text, char from, char to);
 long count_words (char *text);
+void fprintf2(FILE *file, long filesize, const char *fmt, ...);
 void print_line (FILE * outfile, char c, long nn, long flag);
 void sprint_line (char *buffer, char c, long nn, long flag);
 void add_to_buffer(char *fp, long *bufsize, char **buffer, long *allocbufsize);
@@ -3222,6 +3223,24 @@ calc_gamma (MYREAL alpha, MYREAL *gama, long categs)
 }
 
 
+void
+fprintf2(FILE *file, long filesize, const char *fmt, ...)
+{
+    char *p;
+    va_list ap;
+    long bufsize;
+    long pallocsize = filesize+strlen(fmt)+1;
+    p  = (char *) mycalloc(pallocsize,sizeof(char));
+    va_start(ap, fmt);
+    bufsize = vsprintf(p, fmt, ap);
+    if(bufsize>=pallocsize)
+      error("failed in printf2()");
+    fprintf(file,"%s", p);
+    va_end(ap);
+    myfree(p);
+}
+
+
 void
 print_line (FILE * outfile, char c, long nn, long flag)
 {
